// Crypt Kicker
// Backtracking testant toutes les permutations compatibles

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <iostream>
#include <map>
#include <vector>
#include <utility>
#include <queue>

char permutation_en_cours[26];
char perm_inverse[26];
int nmot; // nombre de mots sur la ligne courante
// stocke les mots du dico selon leur cle
// "map" associe des objets a une cle
std::map<std::pair<unsigned long, unsigned long>, std::vector<int> > indices;
char ligne[50][18]; // ligne en cours
char *ligne2[50]; // pour reordonner les mots de la ligne
char dico[1000][18]; // mots du dico

// pour trier les mots de la ligne (par priority_queue)
struct occ{
  int nb, position;
  occ(int a, int b):nb(a),position(b){}
  occ(){}
  bool operator < (const occ& o) const
  { return (nb > o.nb);}
};

// a chaque mot on associe une cle (une paire de unsigned long)
std::pair<unsigned long, unsigned long> mot_to_cle(char *s)
{
  unsigned long l=0, m=0; // codent les positions en base 17
  int positions[26];
  memset (positions,255,26*sizeof(int)); // remplit positions avec des -1
  int i=0, j;
  int min=1; // position courante
  // premier groupe de 8 caracteres
  while (i<8 && s[i] != '\0')
    {
      j = s[i]-'a';
      if (positions[j]<0)
	{
	  positions[j] = min;
	  ++min;
	}
      l = 17*l+positions[j];
      ++i;
    }
  // second groupe de caracteres
  while (s[i] != '\0')
    {

      j = s[i]-'a';
      if (positions[j]<0)
	{
	  positions[j] = min;
	  ++min;
	}
      m = 17*m+positions[j];
      ++i;
    }

  return std::make_pair(l,m);
}

// teste mot apres mot les permutations compatibles
bool backtrack(int n)
{
  std::pair<unsigned long, unsigned long> cle; // cle du mot en cours
  bool b;
  int k;
  int d;
  char copie_permutation[26]; // pour revenir en arriere
  char copie_perm_inverse[26]; // pour revenir en arriere
  memcpy(copie_permutation, permutation_en_cours, 26*sizeof(char));
  memcpy(copie_perm_inverse, perm_inverse, 26*sizeof(char));

  if (n>=nmot) return true;

  cle = mot_to_cle (ligne2[n]); // calculer la cle du mot n
  // boucle sur l'ensemble des permutations possibles
  for (int i=0, fin=indices[cle].size(); i<fin; ++i)
    {
      int j=0;
      b=true;
      k=indices[cle][i];
      while (dico[k][j] != '\0') // boucle sur les lettres du mot du dico
	{
	  d = dico[k][j]-'a';
	  // si la perm en cours est compatible, l'ajouter
	  if ((permutation_en_cours[d] == 0
	      || permutation_en_cours[d] == ligne2[n][j])
	      && (perm_inverse[ligne2[n][j]-'a'] == d + 'a'
		  || perm_inverse[ligne2[n][j]-'a'] == 0))
	    {
	      permutation_en_cours[d] = ligne2[n][j];
	      perm_inverse[ligne2[n][j]-'a'] = d + 'a';
	    }
	  else
	    {b=false; break;}
	  ++j;
	}
      // lancer la procedure recursivement
      if (b && backtrack(n+1)) return true;
      // revenir a la permutation precedente
      memcpy(permutation_en_cours, copie_permutation, 26*sizeof(char));
      memcpy(perm_inverse, copie_perm_inverse, 26*sizeof(char));
    }
  // on n'a pas trouve de permutation
  return false;
}

int main()
{
  int n; // nombre de mots dans le dico
  bool eof = false;
  // mise a jour du dico et des indices
  std::cin >> n;
  for (int i=0; i<n; ++i)
    {
      std::cin >> dico[i];
      indices[mot_to_cle(dico[i])].push_back(i);
    }

  std::cin.get();
  // lecture des phrases
  while (!eof) // boucle sur les lignes
    {
      std::priority_queue<occ> tri;
      nmot=0;
      if (std::cin.peek() == EOF)
	{ eof = true; continue; }
      while (std::cin.peek() != '\n') // boucle sur les mots de la ligne
	{
	  std::cin >> ligne[nmot]; // lire le mot courant
	  ++nmot;
	}
      std::cin.get();
      // réordonner les mots par nb occurrences croissants dans dico
      for (int i=0; i<nmot; ++i)
	tri.push(occ(indices[mot_to_cle(ligne[i])].size(),i));
      for (int i=0; i<nmot; ++i)
	{
	  ligne2[i]=ligne[tri.top().position];
	  tri.pop();
	}
      // initialiser la permutation en cours a 0
      memset(permutation_en_cours,0,26*sizeof(char));
      memset(perm_inverse,0,26*sizeof(char));

      // s'il existe une permutation, afficher la phrase decodee
      if (backtrack(0))
	for (int i=0; i<nmot;++i)
	  {
	    int j=0;
	    while (ligne[i][j] != '\0')
	      {
		int k=0;
		while (permutation_en_cours[k]!=ligne[i][j]) ++k;
		std::cout << (char)(k+'a');
		++j;
	      }
	    if (i<nmot-1) std::cout << ' ';
	  }
      else // sinon des asterisques
	for (int i=0; i<nmot;++i)
	  {
	    int j=0;
	    while (ligne[i][j] != '\0')
	      {
		std::cout << '*';
		++j;
	      }
	    if (i<nmot-1) std::cout << ' ';
	  }
      std::cout << std::endl;

    }
}
